@@ -13,6 +13,9 @@ namespace MainWindowUtils{
 QString beautifyToolTip(const QString& text);
 }
 
+/**
+Core implementation.
+*/
 class Core : public KDevCore
 {
   Q_OBJECT
@@ -23,13 +26,10 @@ public:
 
   ~Core();
 
-  virtual void insertNewAction( KAction* action );
-
   virtual void running(KDevPlugin *which, bool runs);
   virtual void fillContextMenu(QPopupMenu *popup, const Context *context);
   virtual void openProject(const QString& projectFileName);
 
-
   void doEmitProjectOpened() { emit projectOpened(); }
   void doEmitProjectClosed() { emit projectClosed(); }
   void doEmitLanguageChanged() { emit languageChanged(); }
@@ -47,8 +47,7 @@ signals:
 protected:
 
   Core();
-
-
+  
 private:
   static Core *s_instance;
 
